@@ -9,11 +9,13 @@ import publication
 import typing_extensions
 
 import aws_cdk._jsii
+import aws_prototyping_sdk.pdk_nag._jsii
+import cdk_nag._jsii
 import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pipeline", "0.3.8", __name__[0:-6], "pipeline@0.3.8.jsii.tgz"
+    "@aws-prototyping-sdk/pipeline", "0.3.9", __name__[0:-6], "pipeline@0.3.9.jsii.tgz"
 )
 
 __all__ = [
